/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xb0,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xff,0x9,0x35,0x15,0x0,0x96,0x5c,0x51,0x1d,0x30,0x73,0x1b,
  0x3f,0xd3,0x19,0x31,0x65,0x2,0xc9,0xa1,0x4e,0x48,0xe0,0x51,0x98,0xf5,0x9b,0x7d,
  0xd9,0x1,0x89,0x35,0x87,0x9a,0x30,0x30,0xa4,0xa8,0x4b,0x0,0x48,0x0,0x4a,0x0,
  0xb9,0x88,0xa8,0xef,0x96,0x62,0xca,0x8b,0x4b,0x71,0x4b,0xea,0x3c,0x3f,0xd,0x4,
  0x4,0xc8,0xe3,0x4f,0xdc,0xef,0xb5,0x4,0x71,0xbf,0xba,0xc6,0xeb,0x80,0x28,0x8a,
  0x5e,0x13,0x15,0xa0,0xa8,0x94,0x46,0x8,0xc8,0xac,0xad,0x22,0x1f,0x81,0x9c,0xb1,
  0x42,0x65,0x0,0x77,0x4f,0x23,0xd8,0xc0,0xc2,0x8,0x35,0xc5,0xab,0xd0,0xf3,0x80,
  0xa8,0x2d,0xdf,0x62,0xa1,0x4,0x52,0x57,0xb1,0x7e,0x1,0x2f,0x63,0xeb,0x8,0x81,
  0xff,0x68,0xd5,0x45,0x11,0xce,0xbd,0xf,0x1f,0x10,0x1a,0x3c,0xb1,0x7f,0xbd,0xa1,
  0x4a,0x1a,0x2f,0xc7,0xb4,0x34,0xab,0x26,0x77,0x75,0x2c,0x36,0xc7,0x3d,0x21,0xea,
  0x2e,0xe9,0x36,0x37,0x6,0xfd,0x64,0x90,0xc2,0xbd,0xee,0xfb,0xa2,0x42,0x78,0x13,
  0xb3,0x3c,0xca,0xd0,0xcd,0x46,0xc4,0xd3,0x77,0xcf,0x14,0x39,0x8b,0x58,0xcc,0xcf,
  0x72,0x5a,0xbb,0xd3,0x83,0xa3,0x5b,0x79,0xdf,0x86,0x56,0x9a,0x98,0x8e,0x4b,0x4e,
  0xd4,0xb5,0xd6,0xcc,0xe9,0x26,0x9c,0x5b,0x48,0x2f,0x4b,0x89,0x6e,0x72,0x72,0x9b,
  0x68,0xbc,0x2c,0x55,0xf1,0x1d,0x9d,0x78,0xb5,0x3a,0xd1,0x97,0xd7,0x9d,0x3e,0x64,
  0x96,0x62,0x24,0xa6,0x12,0xee,0xff,0xea,0xf0,0x16,0x91,0x3f,0x2b,0x37,0x7c,0xbd,
  0x3c,0xf,0x50,0xf7,0x97,0x3a,0x9d,0xb4,0x65,0xd5,0x38,0x1b,0x1,0x80,0x96,0x9c,
  0xe,0x8f,0x32,0x30,0xbe,0x71,0xb9,0x22,0x9c,0x5e,0xb2,0xf1,0x62,0x27,0x94,0xbb,
  0xf1,0xfe,0xc6,0xa5,0xcc,0x2d,0xed,0x77,0x1f,0x34,0x56,0xcb,0x5d,0xd7,0x32,0xe8,
  0xf7,0x5b,0x2a,0xaa,0xab,0xcb,0xd5,0xae,0xb1,0xfa,0xd4,0x4,0x63,0x3,0xf5,0xfa,
  0xbd,0x92,0xf4,0x25,0xbf,0xb7,0x22,0xf6,0xaf,0xdd,0x44,0xe5,0xcd,0xe7,0x96,0x2c,
  0x1,0x80,0xa8,0xa8,0x71,0xca,0xd0,0x90,0xc8,0x68,0x52,0x90,0x42,0x1a,0x3,0x30,
  0x44,0x40,0xc,0x67,0x5a,0x7,0x42,0x38,0x40,0x14,0x24,0x19,0x4,0xe5,0x28,0x8,
  0x81,0x88,0x0,0x12,0x49,0x88,0x31,0x4d,0x74,0x2b,0x63,0x39,0x3e,0x90,0x63,0x42,
  0xac,0x9f,0xe2,0xd7,0xd,0xa5,0xf4,0x10,0x7a,0x1e,0x91,0xdd,0x94,0x4,0x85,0x10,
  0x2f,0xb9,0x60,0x5b,0x63,0x62,0x91,0xbd,0x63,0x96,0x90,0xd2,0xbd,0xcb,0xc7,0xef,
  0x32,0x82,0xda,0x93,0xec,0xef,0x1e,0x48,0x18,0x95,0x84,0x2f,0xf7,0x67,0xa,0x5c,
  0x6a,0x4a,0x76,0x9b,0x8f,0x77,0xd9,0xba,0xbb,0x89,0x73,0xca,0x67,0xb8,0xbd,0x11,
  0x83,0x1,0xba,0x1c,0xb6,0x31,0xce,0x96,0x84,0x18,0x8a,0xde,0x7c,0xee,0x12,0xbb,
  0x82,0xd,0x4d,0x32,0xb8,0x69,0x10,0x70,0xce,0x11,0x8,0xcc,0x23,0x7f,0x8f,0x21,
  0x3b,0x6b,0xcd,0xa5,0xca,0x2,0x8e,0x12,0x8,0xc6,0x44,0xc4,0xf9,0x3b,0x8a,0xf0,
  0x9f,0x1e,0x1c,0x9b,0x53,0x6d,0x59,0xc6,0x8b,0xc3,0x33,0x29,0xb0,0x89,0xef,0xfe,
  0xaa,0x73,0x7b,0x4e,0xba,0x17,0x5f,0xbc,0x88,0xb,0xaf,0xb4,0x7d,0xe3,0x59,0x88,
  0x52,0xe4,0xb3,0x58,0x9a,0xfa,0x81,0x7c,0x47,0x64,0xf0,0x4c,0xb5,0x10,0x99,0xdd,
  0x86,0x4c,0xa6,0xd8,0x94,0x2,0xad,0x94,0xe0,0xe,0xa7,0xb6,0x41,0xc0,0x10,0x27,
  0x1b,0x99,0xe3,0x6e,0x68,0xa,0x42,0xb,0x92,0x6c,0x6f,0x7c,0x86,0x6f,0x1c,0x52,
  0x2b,0x6,0x2e,0x52,0xff,0x75,0xb6,0xde,0x5c,0x7,0xe6,0x6f,0x80,0xd8,0x60,0x2d,
  0x66,0x83,0x52,0x87,0x5c,0xc4,0xce,0xdd,0xc6,0x5e,0x51,0x8,0xd2,0x32,0x9e,0xf7,
  0xfb,0x17,0x49,0x72,0x9,0x89,0xd6,0x7c,0xe2,0x2b,0x72,0xe7,0x4b,0x51,0x47,0x7b,
  0x3f,0x29,0x3c,0xff,0x2,0xb,0xea,0x20,0x4f,0x9e,0x57,0x25,0x83,0x15,0xa1,0xf5,
  0xed,0x34,0xc,0x8d,0x61,0x32,0xfa,0x86,0xb,0x28,0x70,0x4c,0xf4,0x9a,0x70,0xd2,
  0x62,0xb8,0xcb,0xb0,0xad,0x68,0xf4,0xd8,0xf0,0x78,0xf,0x53,0x89,0xdc,0x42,0xfe,
  0xa,0xb2,0x5c,0x9b,0x7e,0xc5,0x28,0x8a,0x10,0xaa,0x72,0x9f,0xcf,0xca,0xab,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // RpiImager
  0x0,0x9,
  0xe,0x3,0xcf,0x2,
  0x0,0x52,
  0x0,0x70,0x0,0x69,0x0,0x49,0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x72,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x5,0xc8,0x38,0xf8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x5,0xc8,0x38,0xf8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x5,0xc8,0x38,0xf8,
  // :/qt/qml/RpiImager
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x5,0xc8,0x38,0xf8,
  // :/qt/qml/RpiImager/qmldir
  0x0,0x0,0x0,0x2e,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x5,0xc8,0x38,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_RpiImager)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_RpiImager)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_RpiImager)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_RpiImager)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_RpiImager)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_RpiImager)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
